# Level 0

Sometimes, what seems simple actually is complex
Other times, what seems complex is actually simple
More common still, what seems complex is truly complex
And what seems simple is truly simple
